#
# spec file for package SDL2
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           SDL2
%define lname   libSDL2-2_0-0
Version:        2.0.3
Release:        9.3
Summary:        Simple DirectMedia Layer Library
License:        Zlib
Group:          Development/Libraries/X11
Url:            http://libsdl.org/

#DL-URL:        http://libsdl.org/download-2.0.php
Source:         http://libsdl.org/release/%name-%version.tar.gz
Source2:        http://libsdl.org/release/%name-%version.tar.gz.sig
Source3:        %name.keyring
Source4:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  nasm
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa) >= 0.9.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
%if 0%{?suse_version} > 1120
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(glesv1_cm)
BuildRequires:  pkgconfig(glesv2)
%endif
BuildRequires:  pkgconfig(ice)
%if 0%{?suse_version} > 1220
BuildRequires:  pkgconfig(tslib)
%endif
BuildRequires:  pkgconfig(x11)
%if 0%{?suse_version} > 1120
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xxf86vm)
%endif
BuildRequires:  pkgconfig(libpulse-simple) >= 0.9
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
%ifarch ppc ppc64
BuildRequires:  libspe2-devel
%endif

%description
This is the "Simple DirectMedia Layer" library. It provides a generic
API for access to audio, keyboard, mouse, and display framebuffer
across multiple platforms.

%package -n %lname
Summary:        Simple DirectMedia Layer Library
Group:          System/Libraries
Provides:       SDL2 = %version-%release

%description -n %lname
This is the "Simple DirectMedia Layer" library. It provides a generic
API for access to audio, keyboard, mouse, and display framebuffer
across multiple platforms.

%package -n libSDL2-devel
Summary:        SDL2 Library Developer Files
Group:          Development/Libraries/X11
Requires:       %lname = %version
Requires:       c_compiler
Requires:       pkgconfig
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glesv1_cm)
Requires:       pkgconfig(glesv2)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xproto)
Provides:       SDL2-devel = %version-%release

%description -n libSDL2-devel
This package contains files needed for development with the SDL2
library.

%prep
%setup -q
dos2unix WhatsNew.txt
dos2unix TODO.txt
dos2unix BUGS.txt
dos2unix README-SDL.txt
dos2unix README.txt
dos2unix CREDITS.txt
dos2unix COPYING.txt

%build
# In this instance, we do want --with-pic because of libSDL2main.a.
%configure --with-pic \
    --disable-rpath \
    --disable-alsa-shared \
    --disable-video-directfb
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la
# We do not want static libs, but using --disable-static leads to make aborting
# halfway through. SDL2main.a we need to keep(?) for the stub symbol.
find "%buildroot/%_libdir" -type f -name "*.a" ! -name "libSDL2main.a" -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc BUGS.txt COPYING.txt CREDITS.txt README.txt README-SDL.txt
%_libdir/libSDL2-2*.so.*

%files -n libSDL2-devel
%defattr(-,root,root)
%doc TODO.txt WhatsNew.txt
%_bindir/sdl2-config
%_libdir/libSDL2.so
%_libdir/libSDL2main.a
%_includedir/SDL2/
%_datadir/aclocal/sdl2.m4
%_libdir/pkgconfig/sdl2.pc

%changelog
* Mon Jan 12 2015 schwab@suse.de
- libspe2 only exists for ppc and ppc64
* Fri Dec 19 2014 jengelh@inai.de
- Drop old arts/esound soundserver support.
* Thu Dec 18 2014 jengelh@inai.de
- Remove SDL2 obsoletes (we never had packages of that name).
  Copy current Provides to baselibs.conf.
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 2.0.3
  * This is a minor bugfix release to take care of creating an OpenGL
  context on Mac OS X.
* Mon May 26 2014 mailaender@opensuse.org
- Added missing build dependencies
  * arts
  * dbus
  * udev
  * tslib
- Removed unrecognized options: --disable-video-svga, --disable-video-ps3
* Mon May 26 2014 mailaender@opensuse.org
- Use pkgconfig everywhere
- Fix the build on SLE using prjconf
* Thu Mar 13 2014 mailaender@opensuse.org
- Update to 2.0.2
  * Added SDL_GL_ResetAttributes() to reset OpenGL attributes to default values
  * Added an API to load a database of game controller mappings from a file:
    SDL_GameControllerAddMappingsFromFile(), SDL_GameControllerAddMappingsFromRW()
  * Added game controller mappings for the PS4 and OUYA controllers
  * Added SDL_GetDefaultAssertionHandler() and SDL_GetAssertionHandler()
  * Added SDL_DetachThread()
  * Added SDL_HasAVX() to determine if the CPU has AVX features
  * Added SDL_vsscanf(), SDL_acos(), and SDL_asin() to the stdlib routines
  * EGL can now create/manage OpenGL and OpenGL ES 1.x/2.x contexts, and share
    them using SDL_GL_SHARE_WITH_CURRENT_CONTEXT
  * Added a field "clicks" to the mouse button event which records whether the event is a single click, double click, etc.
  * The screensaver is now disabled by default, and there is a hint SDL_HINT_VIDEO_ALLOW_SCREENSAVER that can change that behavior.
  * Added a hint SDL_HINT_MOUSE_RELATIVE_MODE_WARP to specify whether mouse relative mode should be emulated using mouse warping.
  * testgl2 does not need to link with libGL anymore
  * Added testgles2 test program to demonstrate working with OpenGL ES 2.0
  * Added controllermap test program to visually map a game controller
  * Fixed fullscreen and focused behavior when receiving NotifyGrab events
  * Added experimental Wayland and Mir support, disabled by default
- Added SDL2-devel provides
* Thu Nov  7 2013 mailaender@opensuse.org
- Update to version 2.0.1:
  * Added an API to get common filesystem paths in SDL_filesystem.h:
    SDL_GetBasePath(), SDL_GetPrefPath()
  * Added an API to do optimized YV12 and IYUV texture updates:
    SDL_UpdateYUVTexture()
  * Added an API to get the amount of RAM on the system:
    SDL_GetSystemRAM()
  * Added a macro to perform timestamp comparisons with SDL_GetTicks():
    SDL_TICKS_PASSED()
  * Dramatically improved OpenGL ES 2.0 rendering performance
  * Added OpenGL attribute SDL_GL_FRAMEBUFFER_SRGB_CAPABLE
  * Fixed float audio support with the PulseAudio driver
  * Fixed missing line endpoints in the OpenGL renderer on some drivers
  * X11 symbols are no longer defined to avoid collisions when linking statically
* Mon Oct 28 2013 prusnak@opensuse.org
- add SDL2 provides
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list, more robust make install call
- Reduce build dependencies
- Optional signature verification in local builds
* Tue Aug 13 2013 prusnak@opensuse.org
- created package (version 2.0.0) - based on SDL package
